@@ -1,12 +1,11 @@
 use crate::hashmaps::FxHashMap as HashMap;
 
-use crate::pyo3_prelude::*;
+use crate::{circuit::canonicalize::deep_canonicalize, pyo3_prelude::*, timed};
 use num_bigint::BigUint;
 
 use super::{
-    algebraic_rewrite::{add_outer_product_broadcasts_on_top, distribute, get_removable_axes},
+    algebraic_rewrite::distribute,
     circuit_optimizer::{OptimizationContext, OptimizationSettings},
-    circuit_utils::{sum_of_node_sizes_cached, total_flops_cached},
     deep_map_op_context,
     deep_rewrite::compiler_simp,
     prelude::*,
@@ -36,20 +35,17 @@ pub fn maybe_distribute_uncached(
     node: &Einsum,
     context: &mut OptimizationContext,
 ) -> Option<CircuitRc> {
+    if context.cache.times_distributed > 10000 {
+        println!("compiler hit distribute limit");
+        return None;
+    }
     for (i, operand) in node.children().enumerate() {
-        if node.max_non_input_size() >= BigUint::from(context.settings.distribute_min_size)
-            && let Circuit::Add(add) = &**operand
-            && (add_outer_product_broadcasts_on_top(add).is_some() ||  add.children().any(|child| {
-                !get_removable_axes(&child).is_empty()
-                || matches!(&**child, Circuit::Einsum(_) | Circuit::Scatter(_))
-               }))
+        if let Circuit::Add(_add) = &**operand && !_add.nodes.is_empty()&& ( operand.info().numel() >= BigUint::from(context.settings.distribute_min_size.unwrap_or(context.cache.max_single_tensor_numel)))
 
         {
-            let noderc = node.clone().rc();
-            let result = compiler_simp(&distribute(node, i, true).unwrap().rc(),context);
-            if result.info().max_non_input_size < node.info().max_non_input_size ||total_flops_cached(result.clone(),&mut context.cache.flops)<total_flops_cached(noderc.clone(),&mut context.cache.flops)||sum_of_node_sizes_cached(result.clone(),&mut context.cache.sum_of_node_sizes)<sum_of_node_sizes_cached(noderc,&mut context.cache.sum_of_node_sizes){
-                return Some(result);
-            }
+            let result = timed!(deep_canonicalize( compiler_simp(&distribute(node, i, true).unwrap().rc(),context),context),1,context.settings.verbose>=3);
+            context.cache.times_distributed+=1;
+            return Some(result);
         }
     }
     None
@@ -58,10 +54,7 @@ pub fn maybe_distribute_uncached(
 #[pyfunction]
 #[pyo3(name = "deep_maybe_distribute")]
 pub fn deep_maybe_distribute_py(node: CircuitRc, settings: OptimizationSettings) -> CircuitRc {
-    let mut context = OptimizationContext {
-        settings,
-        cache: Default::default(),
-    };
+    let mut context = &mut OptimizationContext::new_settings(settings);
     deep_maybe_distribute(&node, &mut context)
 }
 
