@@ -350,11 +350,21 @@ impl Einsum {
 
     #[staticmethod]
     pub fn from_einsum_string(
-        string: String,
+        string: &str,
         nodes: Vec<CircuitRc>,
         name: Option<String>,
     ) -> Result<Self, CircuitConstructionError> {
-        let (input_ints, output_ints) = EinsumSpec::string_to_ints(string);
+        let (input_ints, output_ints) = EinsumSpec::string_to_ints(string.to_owned());
+        Self::try_new(zip(nodes, input_ints).collect(), output_ints, name)
+    }
+
+    #[staticmethod]
+    pub fn from_fancy_string(
+        string: &str,
+        nodes: Vec<CircuitRc>,
+        name: Option<String>,
+    ) -> Result<Self, CircuitConstructionError> {
+        let (input_ints, output_ints) = EinsumSpec::fancy_string_to_ints(string.to_owned());
         Self::try_new(zip(nodes, input_ints).collect(), output_ints, name)
     }
 
@@ -404,6 +414,14 @@ impl Einsum {
             .copied()
             .collect()
     }
+
+    pub fn next_axis(&self) -> u8 {
+        self.input_axes()
+            .flatten()
+            .max()
+            .map(|x| x + 1)
+            .unwrap_or(0)
+    }
 }
 
 /// Add supports broadcasting
