@@ -1,7 +1,11 @@
+use crate::circuit::generalfunction_rewrite::generalfunction_evaluate_simple;
 use crate::circuit::scatter_rewrite::concat_to_scatter;
 use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 
-use crate::circuit::deep_map_op_context;
+use crate::circuit::{
+    deep_map_op_context, generalfunction_merge_inverses,
+    generalfunction_special_case_simplification,
+};
 use crate::util::{apply_fn_until_same, mapping_until_end, AsOp};
 use crate::{pyo3_prelude::*, timed_value};
 use num_bigint::BigUint;
@@ -85,6 +89,7 @@ pub fn compiler_simp_step(
                 l_wrap!(|x| add_pull_removable_axes(x, true)),
                 f_wrap!(add_pull_scatter),
                 f_wrap!(add_pull_diags),
+                f_wrap!(add_fuse_scalar_multiples),
             ];
             simp(node, fns, context)
         }
@@ -135,6 +140,8 @@ pub fn compiler_simp_step(
         Circuit::GeneralFunction(node) => {
             let fns: &[(&'static str, &dyn Fn(&GeneralFunction) -> _)] = &[
                 l_wrap!(generalfunction_pull_removable_axes),
+                l_wrap!(generalfunction_merge_inverses),
+                l_wrap!(generalfunction_special_case_simplification),
                 l_wrap!(generalfunction_evaluate_simple),
             ];
             simp(node, fns, context)
