@@ -15,6 +15,9 @@ pub use computational_node::{
 };
 pub use constant::{ArrayConstant, ScalarConstant, Symbol};
 pub use generalfunction::{GeneralFunction, GeneralFunctionSpec, PyGFSpecShapeGetter};
+pub use generalfunction_rewrite::{
+    generalfunction_merge_inverses, generalfunction_special_case_simplification,
+};
 pub use module_nodes::{ModuleNode, ModuleNodeArgSpec, ModuleNodeSpec};
 use num_bigint::BigUint;
 use py_circuit_items::circuit_rust_to_py;
@@ -46,6 +49,7 @@ pub mod debugging;
 pub mod deep_rewrite;
 pub mod diag_rewrite;
 pub mod generalfunction;
+pub mod generalfunction_rewrite;
 pub mod module_nodes;
 pub mod named_axes;
 pub mod nrc;
