@@ -310,6 +310,26 @@ impl RearrangeSpec {
             .join(" ");
         input_letters + " -> " + &output_letters
     }
+
+    pub fn add_batch_dims(&self, batch_rank: usize) -> Self {
+        let to_prepend =
+            || (self.int_sizes.len()..self.int_sizes.len() + batch_rank).map(|x| sv![x as u8]);
+        Self {
+            input_ints: to_prepend()
+                .chain(self.input_ints.iter().cloned())
+                .collect(),
+            output_ints: to_prepend()
+                .chain(self.output_ints.iter().cloned())
+                .collect(),
+            int_sizes: self
+                .int_sizes
+                .iter()
+                .cloned()
+                .chain(vec![OpSize::f(None); batch_rank].into_iter())
+                .collect(),
+        }
+    }
+
     pub fn letter_sizes(&self) -> Vec<(String, u64)> {
         // because to_einops_string uses numerals on all added dims, we only need letter sizes for splits
         let ints_needing_sizes: HashSet<EinInt> = self
